# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/package_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/package_service.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B\030PackageServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,com/daml/ledger/api/v1/package_service.proto\x12\x16\x63om.daml.ledger.api.v1\"2\n\x13ListPackagesRequest\x12\x1b\n\tledger_id\x18\x01 \x01(\tR\x08ledgerId\"7\n\x14ListPackagesResponse\x12\x1f\n\x0bpackage_ids\x18\x01 \x03(\tR\npackageIds\"O\n\x11GetPackageRequest\x12\x1b\n\tledger_id\x18\x01 \x01(\tR\x08ledgerId\x12\x1d\n\npackage_id\x18\x02 \x01(\tR\tpackageId\"\x9c\x01\n\x12GetPackageResponse\x12I\n\rhash_function\x18\x01 \x01(\x0e\x32$.com.daml.ledger.api.v1.HashFunctionR\x0chashFunction\x12\'\n\x0f\x61rchive_payload\x18\x02 \x01(\x0cR\x0e\x61rchivePayload\x12\x12\n\x04hash\x18\x03 \x01(\tR\x04hash\"U\n\x17GetPackageStatusRequest\x12\x1b\n\tledger_id\x18\x01 \x01(\tR\x08ledgerId\x12\x1d\n\npackage_id\x18\x02 \x01(\tR\tpackageId\"h\n\x18GetPackageStatusResponse\x12L\n\x0epackage_status\x18\x01 \x01(\x0e\x32%.com.daml.ledger.api.v1.PackageStatusR\rpackageStatus*,\n\rPackageStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nREGISTERED\x10\x01*\x1a\n\x0cHashFunction\x12\n\n\x06SHA256\x10\x00\x32\xd7\x02\n\x0ePackageService\x12i\n\x0cListPackages\x12+.com.daml.ledger.api.v1.ListPackagesRequest\x1a,.com.daml.ledger.api.v1.ListPackagesResponse\x12\x63\n\nGetPackage\x12).com.daml.ledger.api.v1.GetPackageRequest\x1a*.com.daml.ledger.api.v1.GetPackageResponse\x12u\n\x10GetPackageStatus\x12/.com.daml.ledger.api.v1.GetPackageStatusRequest\x1a\x30.com.daml.ledger.api.v1.GetPackageStatusResponseB\x9c\x01\n\x16\x63om.daml.ledger.api.v1B\x18PackageServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
)

_PACKAGESTATUS = _descriptor.EnumDescriptor(
  name='PackageStatus',
  full_name='com.daml.ledger.api.v1.PackageStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REGISTERED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=614,
  serialized_end=658,
)
_sym_db.RegisterEnumDescriptor(_PACKAGESTATUS)

PackageStatus = enum_type_wrapper.EnumTypeWrapper(_PACKAGESTATUS)
_HASHFUNCTION = _descriptor.EnumDescriptor(
  name='HashFunction',
  full_name='com.daml.ledger.api.v1.HashFunction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHA256', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=660,
  serialized_end=686,
)
_sym_db.RegisterEnumDescriptor(_HASHFUNCTION)

HashFunction = enum_type_wrapper.EnumTypeWrapper(_HASHFUNCTION)
UNKNOWN = 0
REGISTERED = 1
SHA256 = 0



_LISTPACKAGESREQUEST = _descriptor.Descriptor(
  name='ListPackagesRequest',
  full_name='com.daml.ledger.api.v1.ListPackagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_id', full_name='com.daml.ledger.api.v1.ListPackagesRequest.ledger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ledgerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=122,
)


_LISTPACKAGESRESPONSE = _descriptor.Descriptor(
  name='ListPackagesResponse',
  full_name='com.daml.ledger.api.v1.ListPackagesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_ids', full_name='com.daml.ledger.api.v1.ListPackagesResponse.package_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='packageIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=179,
)


_GETPACKAGEREQUEST = _descriptor.Descriptor(
  name='GetPackageRequest',
  full_name='com.daml.ledger.api.v1.GetPackageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_id', full_name='com.daml.ledger.api.v1.GetPackageRequest.ledger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ledgerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package_id', full_name='com.daml.ledger.api.v1.GetPackageRequest.package_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='packageId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=260,
)


_GETPACKAGERESPONSE = _descriptor.Descriptor(
  name='GetPackageResponse',
  full_name='com.daml.ledger.api.v1.GetPackageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash_function', full_name='com.daml.ledger.api.v1.GetPackageResponse.hash_function', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hashFunction', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='archive_payload', full_name='com.daml.ledger.api.v1.GetPackageResponse.archive_payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='archivePayload', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='com.daml.ledger.api.v1.GetPackageResponse.hash', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hash', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=419,
)


_GETPACKAGESTATUSREQUEST = _descriptor.Descriptor(
  name='GetPackageStatusRequest',
  full_name='com.daml.ledger.api.v1.GetPackageStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_id', full_name='com.daml.ledger.api.v1.GetPackageStatusRequest.ledger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ledgerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package_id', full_name='com.daml.ledger.api.v1.GetPackageStatusRequest.package_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='packageId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=506,
)


_GETPACKAGESTATUSRESPONSE = _descriptor.Descriptor(
  name='GetPackageStatusResponse',
  full_name='com.daml.ledger.api.v1.GetPackageStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_status', full_name='com.daml.ledger.api.v1.GetPackageStatusResponse.package_status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='packageStatus', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=612,
)

_GETPACKAGERESPONSE.fields_by_name['hash_function'].enum_type = _HASHFUNCTION
_GETPACKAGESTATUSRESPONSE.fields_by_name['package_status'].enum_type = _PACKAGESTATUS
DESCRIPTOR.message_types_by_name['ListPackagesRequest'] = _LISTPACKAGESREQUEST
DESCRIPTOR.message_types_by_name['ListPackagesResponse'] = _LISTPACKAGESRESPONSE
DESCRIPTOR.message_types_by_name['GetPackageRequest'] = _GETPACKAGEREQUEST
DESCRIPTOR.message_types_by_name['GetPackageResponse'] = _GETPACKAGERESPONSE
DESCRIPTOR.message_types_by_name['GetPackageStatusRequest'] = _GETPACKAGESTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetPackageStatusResponse'] = _GETPACKAGESTATUSRESPONSE
DESCRIPTOR.enum_types_by_name['PackageStatus'] = _PACKAGESTATUS
DESCRIPTOR.enum_types_by_name['HashFunction'] = _HASHFUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPackagesRequest = _reflection.GeneratedProtocolMessageType('ListPackagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPACKAGESREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.package_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.ListPackagesRequest)
  })
_sym_db.RegisterMessage(ListPackagesRequest)

ListPackagesResponse = _reflection.GeneratedProtocolMessageType('ListPackagesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPACKAGESRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.package_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.ListPackagesResponse)
  })
_sym_db.RegisterMessage(ListPackagesResponse)

GetPackageRequest = _reflection.GeneratedProtocolMessageType('GetPackageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPACKAGEREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.package_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetPackageRequest)
  })
_sym_db.RegisterMessage(GetPackageRequest)

GetPackageResponse = _reflection.GeneratedProtocolMessageType('GetPackageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPACKAGERESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.package_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetPackageResponse)
  })
_sym_db.RegisterMessage(GetPackageResponse)

GetPackageStatusRequest = _reflection.GeneratedProtocolMessageType('GetPackageStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPACKAGESTATUSREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.package_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetPackageStatusRequest)
  })
_sym_db.RegisterMessage(GetPackageStatusRequest)

GetPackageStatusResponse = _reflection.GeneratedProtocolMessageType('GetPackageStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPACKAGESTATUSRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.package_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetPackageStatusResponse)
  })
_sym_db.RegisterMessage(GetPackageStatusResponse)


DESCRIPTOR._options = None

_PACKAGESERVICE = _descriptor.ServiceDescriptor(
  name='PackageService',
  full_name='com.daml.ledger.api.v1.PackageService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=689,
  serialized_end=1032,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPackages',
    full_name='com.daml.ledger.api.v1.PackageService.ListPackages',
    index=0,
    containing_service=None,
    input_type=_LISTPACKAGESREQUEST,
    output_type=_LISTPACKAGESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPackage',
    full_name='com.daml.ledger.api.v1.PackageService.GetPackage',
    index=1,
    containing_service=None,
    input_type=_GETPACKAGEREQUEST,
    output_type=_GETPACKAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPackageStatus',
    full_name='com.daml.ledger.api.v1.PackageService.GetPackageStatus',
    index=2,
    containing_service=None,
    input_type=_GETPACKAGESTATUSREQUEST,
    output_type=_GETPACKAGESTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PACKAGESERVICE)

DESCRIPTOR.services_by_name['PackageService'] = _PACKAGESERVICE

# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

"""
Contains primitive declarations and functions for working with "native" Python types as they
correspond to types over the Ledger API.
"""

from .basic import (
    LEDGER_STRING_REGEX,
    NAME_STRING_REGEX,
    PACKAGE_ID_STRING_REGEX,
    PARTY_ID_STRING_REGEX,
    to_bool,
    to_str,
)
from .complex import to_record, to_variant
from .contracts import ContractData, ContractId
from .datetime import (
    TimeDeltaLike,
    date_to_int,
    date_to_str,
    datetime_to_epoch_microseconds,
    datetime_to_epoch_timedelta,
    datetime_to_str,
    datetime_to_timestamp,
    timedelta_to_duration,
    to_date,
    to_datetime,
    to_timedelta,
)
from .errors import DazlError, DazlWarning
from .json import JSONEncoder
from .map import FrozenDict
from .numbers import decimal_to_str, to_decimal, to_int
from .party import Party, to_party

__all__ = [
    "LEDGER_STRING_REGEX",
    "NAME_STRING_REGEX",
    "PACKAGE_ID_STRING_REGEX",
    "PARTY_ID_STRING_REGEX",
    "to_bool",
    "to_str",
    "to_record",
    "to_variant",
    "ContractData",
    "ContractId",
    "TimeDeltaLike",
    "date_to_int",
    "date_to_str",
    "datetime_to_epoch_microseconds",
    "datetime_to_epoch_timedelta",
    "datetime_to_str",
    "datetime_to_timestamp",
    "timedelta_to_duration",
    "to_date",
    "to_datetime",
    "to_timedelta",
    "DazlError",
    "DazlWarning",
    "JSONEncoder",
    "FrozenDict",
    "decimal_to_str",
    "to_decimal",
    "to_int",
    "Party",
    "to_party",
]



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .config_management_service_pb2 import GetTimeModelRequest, GetTimeModelResponse, SetTimeModelRequest, SetTimeModelResponse, TimeModel
from .config_management_service_pb2_grpc import ConfigManagementServiceStub
from .package_management_service_pb2 import ListKnownPackagesRequest, ListKnownPackagesResponse, PackageDetails, UploadDarFileRequest, UploadDarFileResponse
from .package_management_service_pb2_grpc import PackageManagementServiceStub
from .participant_pruning_service_pb2 import PruneRequest, PruneResponse
from .participant_pruning_service_pb2_grpc import ParticipantPruningServiceStub
from .party_management_service_pb2 import AllocatePartyRequest, AllocatePartyResponse, GetParticipantIdRequest, GetParticipantIdResponse, GetPartiesRequest, GetPartiesResponse, ListKnownPartiesRequest, ListKnownPartiesResponse, PartyDetails
from .party_management_service_pb2_grpc import PartyManagementServiceStub

__all__ = [
    "AllocatePartyRequest",
    "AllocatePartyResponse",
    "ConfigManagementServiceStub",
    "GetParticipantIdRequest",
    "GetParticipantIdResponse",
    "GetPartiesRequest",
    "GetPartiesResponse",
    "GetTimeModelRequest",
    "GetTimeModelResponse",
    "ListKnownPackagesRequest",
    "ListKnownPackagesResponse",
    "ListKnownPartiesRequest",
    "ListKnownPartiesResponse",
    "PackageDetails",
    "PackageManagementServiceStub",
    "ParticipantPruningServiceStub",
    "PartyDetails",
    "PartyManagementServiceStub",
    "PruneRequest",
    "PruneResponse",
    "SetTimeModelRequest",
    "SetTimeModelResponse",
    "TimeModel",
    "UploadDarFileRequest",
    "UploadDarFileResponse",
]
